@@ -1,10 +1,10 @@
-from captur_ml_sdk.dtypes.generics import Image, Meta, Model
+from captur_ml_sdk.dtypes.generics import Image, EvaluationMeta, Model
 from pydantic import BaseModel
 from typing import List, Optional, Dict
 
 
 class ModelEvaluateRequest(BaseModel):
     data: List[Image]
-    meta: Optional[Meta] = None
+    meta: Optional[EvaluationMeta] = None
     models: List[Model]
     mapping: Optional[Dict[str, Dict[str, str]]]
