@@ -24,7 +24,7 @@ class BaseMdl(BaseModel):
 class Model(BaseModel):
     name: str
     base_model: Optional[BaseMdl]
-    include_data: str
+    include_data: List[str]
     exclude_classes: Optional[List[str]]
 
 
